@@ -1,7 +1,8 @@
 use strict; use warnings;
 package Devel::GlobalDestruction::XS;
 
-our $VERSION = '0.05';
+# our $VERSION = '0.01';
+use Alt::Devel::GlobalDestruction::XS::Inline;
 
 use Devel::GlobalDestruction::XS::Inline
     C => 'lib/Devel/GlobalDestruction/XS.c';
